==> lapisworks-1.5.6.5-sources.jar: com/luxof/lapisworks/mixin/EntityMixin.java <==
package com.luxof.lapisworks.mixin;

import com.luxof.lapisworks.mixinsupport.ArtMindInterface;
import com.luxof.lapisworks.mixinsupport.LapisworksInterface;
import com.luxof.lapisworks.mixinsupport.LapisworksInterface.AllEnchantments;
import net.minecraft.class_1282;
import net.minecraft.class_1297;
import net.minecraft.class_1309;
import net.minecraft.class_1646;
import net.minecraft.class_2487;
import net.minecraft.class_5131;
import net.minecraft.class_5132;
import net.minecraft.class_5134;
import net.minecraft.class_8103;

import static com.luxof.lapisworks.Lapisworks.LOGGER;

import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

@Mixin(class_1297.class)
public class EntityMixin {
	@Inject(at = @At("HEAD"), method = "isInvulnerableTo", cancellable = true)
	public void isInvulnerableTo(class_1282 damageSource, CallbackInfoReturnable<Boolean> cir) {
        if ((Object)this instanceof class_1309) {
            if (damageSource.method_48789(class_8103.field_42246) &&
                ((LapisworksInterface)this).getEnchant(AllEnchantments.fireResist) > 0) {
                cir.setReturnValue(true);
            }
        }
	}

    @Inject(at = @At("HEAD"), method = "readNbt")
	public void readNbt(class_2487 nbt, CallbackInfo ci) {
        // oh yeah, it's backwards compat time
        if ((Object)this instanceof class_1309) {
            try {
                ((LapisworksInterface)this).setLapisworksAttributes(new class_5131(
                    class_5132.method_26861()
                    .method_26868(class_5134.field_23721, nbt.method_10574("LAPISWORKS_JUICED_FISTS"))
                    .method_26868(class_5134.field_23723, nbt.method_10574("LAPISWORKS_JUICED_DEX"))
                    .method_26868(class_5134.field_23716, nbt.method_10574("LAPISWORKS_JUICED_SKIN"))
                    .method_26868(class_5134.field_23719, nbt.method_10574("LAPISWORKS_JUICED_FEET"))
                    .method_26866()
                ));
            } catch (Exception e) {
                LOGGER.warn("JUST FOUND AN ERROR, COULDN'T LOAD JUICED ATTRS!");
                e.printStackTrace();
            }
            try {
                ((LapisworksInterface)this).setEnchantments(
                    nbt.method_10561("LAPISWORKS_ENCHANTMENTS")
                );
            } catch (Exception e) {
                LOGGER.warn("couldn't load enchantments!!");
                e.printStackTrace();
            }

            if ((Object)this instanceof class_1646) {
                try {
                    ((ArtMindInterface)this).setUsedMindPercentage(nbt.method_10583("LAPISWORKS_MIND_USED"));
                    ((ArtMindInterface)this).setMindBeingUsedTicks(nbt.method_10550("LAPISWORKS_MIND_HEAL_COOLDOWN"));
                } catch (Exception e) {
                    LOGGER.warn("Couldn't load VillagerEntity shit!");
                    e.printStackTrace();
                }
            }
        }
	}

	@Inject(at = @At("HEAD"), method = "writeNbt")
	public void writeNbt(class_2487 nbt, CallbackInfoReturnable<class_2487> cir) {
        if ((Object)this instanceof class_1309) {
            class_5131 attrs = ((LapisworksInterface)this).getLapisworksAttributes();
            nbt.method_10549("LAPISWORKS_JUICED_FISTS", attrs.method_26856(class_5134.field_23721));
            nbt.method_10549("LAPISWORKS_JUICED_DEX", attrs.method_26856(class_5134.field_23723));
            nbt.method_10549("LAPISWORKS_JUICED_SKIN", attrs.method_26856(class_5134.field_23716));
            nbt.method_10549("LAPISWORKS_JUICED_FEET", attrs.method_26856(class_5134.field_23719));
            nbt.method_10572("LAPISWORKS_ENCHANTMENTS", ((LapisworksInterface)this).getEnchantments());
            if ((Object)this instanceof class_1646) {
                nbt.method_10548("LAPISWORKS_MIND_USED", ((ArtMindInterface)this).getUsedMindPercentage());
                nbt.method_10569("LAPISWORKS_MIND_HEAL_COOLDOWN", ((ArtMindInterface)this).getMindBeingUsedTicks());
            }
        }
	}
}

==> lapisworks-1.5.7-sources.jar: com/luxof/lapisworks/mixin/EntityMixin.java <==
package com.luxof.lapisworks.mixin;

import com.google.common.collect.ImmutableMultimap;

import com.luxof.lapisworks.actions.MoarReachYouBitch;
import com.luxof.lapisworks.mixinsupport.ArtMindInterface;
import com.luxof.lapisworks.mixinsupport.LapisworksInterface;
import com.luxof.lapisworks.mixinsupport.LapisworksInterface.AllEnchantments;
import net.minecraft.class_1282;
import net.minecraft.class_1297;
import net.minecraft.class_1309;
import net.minecraft.class_1646;
import net.minecraft.class_2487;
import net.minecraft.class_5131;
import net.minecraft.class_5132;
import net.minecraft.class_5134;
import net.minecraft.class_8103;

import static com.luxof.lapisworks.Lapisworks.LOGGER;
import static com.luxof.lapisworks.LapisworksIDs.REACH_ENHANCEMENT_UUID;

import static com.jamieswhiteshirt.reachentityattributes.ReachEntityAttributes.ATTACK_RANGE;
import static com.jamieswhiteshirt.reachentityattributes.ReachEntityAttributes.REACH;

import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

@Mixin(class_1297.class)
public class EntityMixin {
	@Inject(at = @At("HEAD"), method = "isInvulnerableTo", cancellable = true)
	public void isInvulnerableTo(class_1282 damageSource, CallbackInfoReturnable<Boolean> cir) {
        if ((Object)this instanceof class_1309) {
            if (damageSource.method_48789(class_8103.field_42246) &&
                ((LapisworksInterface)this).getEnchant(AllEnchantments.fireResist) > 0) {
                cir.setReturnValue(true);
            }
        }
	}

    @Inject(at = @At("HEAD"), method = "readNbt")
	public void readNbt(class_2487 nbt, CallbackInfo ci) {
        // oh yeah, it's backwards compat time
        if ((Object)this instanceof class_1309 living) {
            try {
                ((LapisworksInterface)this).setLapisworksAttributes(new class_5131(
                    class_5132.method_26861()
                    .method_26868(class_5134.field_23721, nbt.method_10574("LAPISWORKS_JUICED_FISTS"))
                    .method_26868(class_5134.field_23716, nbt.method_10574("LAPISWORKS_JUICED_SKIN"))
                    .method_26868(class_5134.field_23719, nbt.method_10574("LAPISWORKS_JUICED_FEET"))
                    .method_26866()
                ));
                living.method_6127().method_26854(
                    nbt.method_10577("LAPISWORKS_JUICED_REACH") ?
                        ImmutableMultimap.of(
                            REACH, MoarReachYouBitch.REACH_MODIFIER,
                            ATTACK_RANGE, MoarReachYouBitch.ATTACK_REACH_MODIFIER
                        ) : ImmutableMultimap.of()
                );
            } catch (Exception e) {
                LOGGER.warn("JUST FOUND AN ERROR, COULDN'T LOAD JUICED ATTRS!");
                e.printStackTrace();
            }
            try {
                ((LapisworksInterface)this).setEnchantments(
                    nbt.method_10561("LAPISWORKS_ENCHANTMENTS")
                );
            } catch (Exception e) {
                LOGGER.warn("couldn't load enchantments!!");
                e.printStackTrace();
            }

            if ((Object)this instanceof class_1646) {
                try {
                    ((ArtMindInterface)this).setUsedMindPercentage(nbt.method_10583("LAPISWORKS_MIND_USED"));
                    ((ArtMindInterface)this).setMindBeingUsedTicks(nbt.method_10550("LAPISWORKS_MIND_HEAL_COOLDOWN"));
                } catch (Exception e) {
                    LOGGER.warn("Couldn't load VillagerEntity shit!");
                    e.printStackTrace();
                }
            }
        }
	}

	@Inject(at = @At("HEAD"), method = "writeNbt")
	public void writeNbt(class_2487 nbt, CallbackInfoReturnable<class_2487> cir) {
        if ((Object)this instanceof class_1309 living) {
            class_5131 attrs = ((LapisworksInterface)this).getLapisworksAttributes();
            nbt.method_10549("LAPISWORKS_JUICED_FISTS", attrs.method_26856(class_5134.field_23721));
            nbt.method_10549("LAPISWORKS_JUICED_SKIN", attrs.method_26856(class_5134.field_23716));
            nbt.method_10549("LAPISWORKS_JUICED_FEET", attrs.method_26856(class_5134.field_23719));
            nbt.method_10572("LAPISWORKS_ENCHANTMENTS", ((LapisworksInterface)this).getEnchantments());
            nbt.method_10556(
                "LAPISWORKS_JUICED_REACH",
                living.method_6127().method_27305(REACH, REACH_ENHANCEMENT_UUID)
            );
            if ((Object)this instanceof class_1646) {
                nbt.method_10548("LAPISWORKS_MIND_USED", ((ArtMindInterface)this).getUsedMindPercentage());
                nbt.method_10569("LAPISWORKS_MIND_HEAL_COOLDOWN", ((ArtMindInterface)this).getMindBeingUsedTicks());
            }
        }
	}
}
